@@ -15,10 +15,15 @@ cursesplus.filedialog : Advanced menus for user-friendly file selection.
 
 cursesplus.messagebox : Package for message-boxes which are messages displayed on top of data instead of over-writing it.
 
+cursesplus.transitions : Module for transitions
+
 """
 
-__version__ = "2.0.0"
+__version__ = "2.11.3"
 __author__ = "Enderbyte Programs"
 __package__ = "cursesplus"
 
-from .cp import *# Maintain backwards compatibility
\ No newline at end of file
+from .cp import *# Maintain backwards compatibility
+from . import transitions as transitions
+from . import filedialog as filedialog
+from . import messagebox as messagebox
\ No newline at end of file
